<!-- content -->

BlPortfolioConstruction is a library which attempts to automate portfolio optimization by adopting a bayesian approach (Black-Litterman model) in conjunction with Factor Analysis and classical mean-variance/max sharpe optimization methods. 
